#ifndef NT2_INCLUDE_CONSTANTS_MTEN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MTEN_HPP_INCLUDED

#include <nt2/constant/include/constants/mten.hpp>

#endif
